# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: th2_grpc_check1/check1.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'th2_grpc_check1/check1.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cth2_grpc_check1/check1.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cth2_grpc_common/common.proto\"K\n\x11\x43heckpointRequest\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12!\n\x0fparent_event_id\x18\x02 \x01(\x0b\x32\x08.EventID\"U\n\x12\x43heckpointResponse\x12\x1f\n\ncheckpoint\x18\x01 \x01(\x0b\x32\x0b.Checkpoint\x12\x1e\n\x06status\x18\x02 \x01(\x0b\x32\x0e.RequestStatus\"\x15\n\x07\x43hainID\x12\n\n\x02id\x18\x01 \x01(\t\"\xd6\x02\n\x10\x43heckRuleRequest\x12&\n\x0f\x63onnectivity_id\x18\x01 \x01(\x0b\x32\r.ConnectionID\x12\'\n\x0broot_filter\x18\n \x01(\x0b\x32\x12.RootMessageFilter\x12\x1f\n\ncheckpoint\x18\x03 \x01(\x0b\x32\x0b.Checkpoint\x12\x17\n\x0fmessage_timeout\x18\x0b \x01(\x03\x12\x0f\n\x07timeout\x18\x04 \x01(\x03\x12\x14\n\x0cstore_result\x18\r \x01(\x08\x12!\n\x0fparent_event_id\x18\x06 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x1d\n\tdirection\x18\x08 \x01(\x0e\x32\n.Direction\x12\x1a\n\x08\x63hain_id\x18\t \x01(\x0b\x32\x08.ChainID\x12\x11\n\tbook_name\x18\x0c \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06\"`\n\x11\x43heckRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\x12\x0f\n\x07rule_id\x18\x03 \x01(\x03\"\xcf\x03\n\x18\x43heckSequenceRuleRequest\x12\x1e\n\npre_filter\x18\x01 \x01(\x0b\x32\n.PreFilter\x12\x30\n\x14root_message_filters\x18\x0c \x03(\x0b\x32\x12.RootMessageFilter\x12\x1f\n\ncheckpoint\x18\x03 \x01(\x0b\x32\x0b.Checkpoint\x12\x17\n\x0fmessage_timeout\x18\r \x01(\x03\x12\x0f\n\x07timeout\x18\x04 \x01(\x03\x12\x14\n\x0cstore_result\x18\x10 \x01(\x08\x12&\n\x0f\x63onnectivity_id\x18\x05 \x01(\x0b\x32\r.ConnectionID\x12!\n\x0fparent_event_id\x18\x07 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x63heck_order\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x1d\n\tdirection\x18\n \x01(\x0e\x32\n.Direction\x12\x1a\n\x08\x63hain_id\x18\x0b \x01(\x0b\x32\x08.ChainID\x12\x31\n\rsilence_check\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x11\n\tbook_name\x18\x0f \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x06\x10\x07\"h\n\x19\x43heckSequenceRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\x12\x0f\n\x07rule_id\x18\x03 \x01(\x03\"\xa0\x01\n\tPreFilter\x12&\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x16.PreFilter.FieldsEntry\x12(\n\x0fmetadata_filter\x18\x03 \x01(\x0b\x32\x0f.MetadataFilter\x1a;\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.ValueFilter:\x02\x38\x01J\x04\x08\x01\x10\x02\"\xc6\x02\n\x15NoMessageCheckRequest\x12\x1e\n\npre_filter\x18\x01 \x01(\x0b\x32\n.PreFilter\x12\x17\n\x0fmessage_timeout\x18\x02 \x01(\x03\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\x12\x14\n\x0cstore_result\x18\x0b \x01(\x08\x12\x1f\n\ncheckpoint\x18\x04 \x01(\x0b\x32\x0b.Checkpoint\x12\x1a\n\x08\x63hain_id\x18\x05 \x01(\x0b\x32\x08.ChainID\x12&\n\x0f\x63onnectivity_id\x18\x06 \x01(\x0b\x32\r.ConnectionID\x12!\n\x0fparent_event_id\x18\x07 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x1d\n\tdirection\x18\t \x01(\x0e\x32\n.Direction\x12\x11\n\tbook_name\x18\n \x01(\t\"e\n\x16NoMessageCheckResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\x12\x0f\n\x07rule_id\x18\x03 \x01(\x03\"S\n\x14WaitForResultRequest\x12\x0f\n\x07rule_id\x18\x01 \x01(\x03\x12*\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"Z\n\x15WaitForResultResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12!\n\x0brule_result\x18\x02 \x01(\x0e\x32\x0c.EventStatus\"u\n\x11MultiRulesRequest\x12)\n\x17\x64\x65\x66\x61ult_parent_event_id\x18\x01 \x01(\x0b\x32\x08.EventID\x12\x1f\n\rdefault_chain\x18\x02 \x01(\x0b\x32\x08.ChainID\x12\x14\n\x05rules\x18\x03 \x03(\x0b\x32\x05.Rule\"6\n\x12MultiRulesResponse\x12 \n\tresponses\x18\x01 \x03(\x0b\x32\r.RuleResponse\"\xa5\x01\n\x04Rule\x12-\n\x10\x63heckRuleRequest\x18\x01 \x01(\x0b\x32\x11.CheckRuleRequestH\x00\x12\x31\n\x0csequenceRule\x18\x02 \x01(\x0b\x32\x19.CheckSequenceRuleRequestH\x00\x12/\n\rnoMessageRule\x18\x03 \x01(\x0b\x32\x16.NoMessageCheckRequestH\x00\x42\n\n\x08one_rule\"[\n\x0cRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\x12\x0f\n\x07rule_id\x18\x03 \x01(\x03\x32\xe9\x03\n\x06\x43heck1\x12=\n\x10\x63reateCheckpoint\x12\x12.CheckpointRequest\x1a\x13.CheckpointResponse\"\x00\x12:\n\x0fsubmitCheckRule\x12\x11.CheckRuleRequest\x1a\x12.CheckRuleResponse\"\x00\x12R\n\x17submitCheckSequenceRule\x12\x19.CheckSequenceRuleRequest\x1a\x1a.CheckSequenceRuleResponse\"\x00\x12I\n\x14submitNoMessageCheck\x12\x16.NoMessageCheckRequest\x1a\x17.NoMessageCheckResponse\"\x00\x12@\n\rwaitForResult\x12\x15.WaitForResultRequest\x1a\x16.WaitForResultResponse\"\x00\x12@\n\x13submitMultipleRules\x12\x12.MultiRulesRequest\x1a\x13.MultiRulesResponse\"\x00\x12\x41\n\x11postMultipleRules\x12\x12.MultiRulesRequest\x1a\x16.google.protobuf.Empty\"\x00\x42 \n\x1c\x63om.exactpro.th2.check1.grpcP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'th2_grpc_check1.check1_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.exactpro.th2.check1.grpcP\001'
  _globals['_PREFILTER_FIELDSENTRY']._loaded_options = None
  _globals['_PREFILTER_FIELDSENTRY']._serialized_options = b'8\001'
  _globals['_CHECKPOINTREQUEST']._serialized_start=155
  _globals['_CHECKPOINTREQUEST']._serialized_end=230
  _globals['_CHECKPOINTRESPONSE']._serialized_start=232
  _globals['_CHECKPOINTRESPONSE']._serialized_end=317
  _globals['_CHAINID']._serialized_start=319
  _globals['_CHAINID']._serialized_end=340
  _globals['_CHECKRULEREQUEST']._serialized_start=343
  _globals['_CHECKRULEREQUEST']._serialized_end=685
  _globals['_CHECKRULERESPONSE']._serialized_start=687
  _globals['_CHECKRULERESPONSE']._serialized_end=783
  _globals['_CHECKSEQUENCERULEREQUEST']._serialized_start=786
  _globals['_CHECKSEQUENCERULEREQUEST']._serialized_end=1249
  _globals['_CHECKSEQUENCERULERESPONSE']._serialized_start=1251
  _globals['_CHECKSEQUENCERULERESPONSE']._serialized_end=1355
  _globals['_PREFILTER']._serialized_start=1358
  _globals['_PREFILTER']._serialized_end=1518
  _globals['_PREFILTER_FIELDSENTRY']._serialized_start=1453
  _globals['_PREFILTER_FIELDSENTRY']._serialized_end=1512
  _globals['_NOMESSAGECHECKREQUEST']._serialized_start=1521
  _globals['_NOMESSAGECHECKREQUEST']._serialized_end=1847
  _globals['_NOMESSAGECHECKRESPONSE']._serialized_start=1849
  _globals['_NOMESSAGECHECKRESPONSE']._serialized_end=1950
  _globals['_WAITFORRESULTREQUEST']._serialized_start=1952
  _globals['_WAITFORRESULTREQUEST']._serialized_end=2035
  _globals['_WAITFORRESULTRESPONSE']._serialized_start=2037
  _globals['_WAITFORRESULTRESPONSE']._serialized_end=2127
  _globals['_MULTIRULESREQUEST']._serialized_start=2129
  _globals['_MULTIRULESREQUEST']._serialized_end=2246
  _globals['_MULTIRULESRESPONSE']._serialized_start=2248
  _globals['_MULTIRULESRESPONSE']._serialized_end=2302
  _globals['_RULE']._serialized_start=2305
  _globals['_RULE']._serialized_end=2470
  _globals['_RULERESPONSE']._serialized_start=2472
  _globals['_RULERESPONSE']._serialized_end=2563
  _globals['_CHECK1']._serialized_start=2566
  _globals['_CHECK1']._serialized_end=3055
# @@protoc_insertion_point(module_scope)
